<?php
/**
 * Dali functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package WordPress
 * Tested up to: 5.8
 * Requires PHP: 7.4
 * @subpackage Dali
 * @since Dali 1.0
 */
/**
 * Assign the Dali version to a var
 */
$theme            = wp_get_theme( 'dali' );
$dali_version     = $theme['Version'];

$dali = (object) array(
	'version'    => $dali_version,
);
require get_template_directory() . '/inc/dali-functions.php';

add_action( 'wp_enqueue_scripts', 'dali_scripts' );

if ( ! function_exists( 'dali_support' ) ) :

	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * @since Dali 1.0
	 *
	 * @return void
	 */
	function dali_support() {

		// Add support for block styles.
		add_theme_support( 'wp-block-styles' );

		add_theme_support( 'appearance-tools' );

		// Add support for responsive embedded content.
		add_theme_support( 'responsive-embeds' );

		add_theme_support( 'custom-line-height' );

		// Enqueue editor styles.
		add_editor_style( 'style.css' );

		add_editor_style( 'editor-style.css' );

		/**
		 * Add default posts and comments RSS feed links to head.
		 */
		add_theme_support( 'automatic-feed-links' );

		/**
		* Declare support for title theme feature.
		*/
		add_theme_support( 'title-tag' );
      
	}

endif;

add_action( 'after_setup_theme', 'dali_support' );


if ( ! function_exists( 'dali_styles' ) ) :

	/**
	 * Enqueue styles.
	 *
	 * @since Dali 1.0
	 *
	 * @return void
	 */
	function dali_styles() {
		// Register theme stylesheet.
		$theme_version = wp_get_theme()->get( 'Version' );

		$version_string = is_string( $theme_version ) ? $theme_version : false;
		wp_register_style(
			'dali-style',
			get_template_directory_uri() . '/style.css',
			array(),
			$version_string
		);

		// Enqueue theme stylesheet.
		wp_enqueue_style( 'dali-style' );

	}

endif;

add_action( 'wp_enqueue_scripts', 'dali_styles' );

// Add block patterns
require get_template_directory() . '/inc/block-patterns.php';
require_once get_template_directory() . '/inc/dali-template-functions.php';
require_once get_template_directory() . '/inc/dali-template-hooks.php';

add_filter( 'masvideos_get_image_size_movie_large','dali_get_image_size_movie_large' );
add_filter( 'masvideos_get_image_size_video_medium','dali_get_image_size_video_medium' );

function dali_get_image_size_movie_large( $size ) {
	$size['width']   = 1000;
	$size['height']  = 1333;
    $size['crop']    = 1;
    return $size;
}

function dali_get_image_size_video_medium( $size ) {
	$size['width']   = 500;
	$size['height']  = 281;
    $size['crop']    = 1;https://dali.madrasthemes.com/elementor/
    return $size;
}

if ( is_admin() ) {
	
	/**
	 * TGM Plugin Activation class.
	 */
	require get_template_directory() . '/inc/classes/class-tgm-plugin-activation.php';
	$dali->plugin_install = require get_template_directory() . '/inc/admin/class-dali-plugin-install.php';

	if ( dali_is_ocdi_activated() ) {
		$dali->ocdi = require get_template_directory() . '/inc/ocdi/class-dali-ocdi.php';
	}
}

add_filter( 'mas_elementor_premium_templates_path', 'dali_premium_templates_path' );

function dali_premium_templates_path( $path ) {
	$path = 'https://dali.madrasthemes.com/elementor/';
	return $path;
}


if ( !function_exists( 'dali_scripts' ) ) {

	/**
	 * Enqueue styles.
	 *
	 * @since dali 1.0
	 *
	 * @return void
	 */
	function dali_scripts() {

		// Enqueueing JS
		if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
			wp_enqueue_script( 'comment-reply' );
		}

		wp_enqueue_script( 'dali-script', get_template_directory_uri() . '/assets/js/script.js', array( 'jquery' ), wp_get_theme()->get('Version'), true );

	}
}

