<?php
/**
 * Dali: Block Patterns
 *
 * @since Dali 1.0
 */

/**
 * Registers block patterns and categories.
 *
 * @since Dali 1.0
 *
 * @return void
 */
function dali_register_block_patterns() {
	$block_pattern_categories = array(
		'featured' => array( 'label' => __( 'Featured', 'dali' ) ),
		'footer'   => array( 'label' => __( 'Footers', 'dali' ) ),
		'header'   => array( 'label' => __( 'Headers', 'dali' ) ),
		'query'    => array( 'label' => __( 'Query', 'dali' ) ),
		'pages'    => array( 'label' => __( 'Pages', 'dali' ) ),
	);

	/**
	 * Filters the theme block pattern categories.
	 *
	 * @since Dali 1.0
	 *
	 * @param array[] $block_pattern_categories {
	 *     An associative array of block pattern categories, keyed by category name.
	 *
	 *     @type array[] $properties {
	 *         An array of block category properties.
	 *
	 *         @type string $label A human-readable label for the pattern category.
	 *     }
	 * }
	 */
	$block_pattern_categories = apply_filters( 'dali_block_pattern_categories', $block_pattern_categories );

	foreach ( $block_pattern_categories as $name => $properties ) {
		if ( ! WP_Block_Pattern_Categories_Registry::get_instance()->is_registered( $name ) ) {
			register_block_pattern_category( $name, $properties );
		}
	}

	$block_patterns = array(
		'dali-archive-header',
		'dali-genre',
		'dali-blog-header',
		'dali-header-default',
		'dali-header-dark',
		'dali-header-transparent',
		'dali-footer-default',
		'footer-default',
		'dali-footer-light',
		'dali-footer-dark-v1',
		'dali-footer-dark-v2',
		'dali-general-movies-dark',
		'dali-general-movies-light',
		'dali-general-movies-style2',
		'dali-general-movies-style3',
		'dali-general-movies-tab',
		'dali-general-faq-dark',
		'dali-general-faq-light',
		'dali-general-price-table-dark',
		'dali-general-price-table-light',
		'dali-general-features',
		'dali-general-features-post',
		'dali-general-page-heading',
		'dali-general-tab-content',
		'dali-general-hero-movies',
		'dali-general-hero-modern',
		'dali-general-app-v1',
		'dali-general-app-v2',
		'dali-general-app-v3',
		'dali-general-app-v4',
		'dali-general-cta-v1',
		'dali-general-cta-v2',
		'dali-general-brand',
		'dali-general-hero-v1',
		'dali-general-hero-v2',
		'dali-popular-tv-shows',
		'dali-general-newsletter-v1',
		'dali-general-newsletter-v2',
		'dali-general-newsletter-v3',
		'dali-general-testimonial-light',
		'dali-general-testimonial-dark',
		'dali-query-default-post',
		'dali-blog-grid',
		'dali-movie-list-with-image',
		'dali-query-featured-movie',
		'dali-general-dark-category',
		'dali-general-category',
		'dali-tv-shows-with-show-list',
		'dali-video-list-with-image',
		'dali-404'
		
	);

	/**
	 * Filters the theme block patterns.
	 *
	 * @since Dali 1.0
	 *
	 * @param array $block_patterns List of block patterns by name.
	 */
	$block_patterns = apply_filters( 'dali_block_patterns', $block_patterns );

	foreach ( $block_patterns as $block_pattern ) {
		$pattern_file = get_theme_file_path( '/inc/patterns/' . $block_pattern . '.php' );

		register_block_pattern(
			'dali/' . $block_pattern,
			require $pattern_file
		);
	}
}
add_action( 'init', 'dali_register_block_patterns', 9 );
