<?php
/**
 * Template functions for loop
*/

/**
 * Video loop items.
*/
if ( ! function_exists( 'dali_template_loop_video_item_open' ) ) {

    /**
     * Video meta close in the video meta.
     */
    function dali_template_loop_video_item_open() {
        echo '<div class="space-y-4 mb-6 video-inner">';
    }
}

if ( ! function_exists( 'dali_get_video_loop_thumbnail' ) ) {
    /**
     * Get the dali thumbnail, or the placeholder if not set.
     */
    function dali_get_video_loop_thumbnail ( $size = 'masvideos_video_medium' ) {
        global $video;

        $image_size = apply_filters( 'dali_video_archive_thumbnail_size', $size );

        $gallery_image_ids = $video ? $video->get_gallery_image_ids() : '';
        $gallery_image_srcs = array();

        if( ! empty( $gallery_image_ids ) ) {
            foreach ( $gallery_image_ids as $gallery_image_id ) {
                $gallery_image_srcs[] =  wp_get_attachment_image_url( $gallery_image_id, $image_size );
            }
        }

        return $video ? $video->get_image( $image_size , array( 'class' => 'w-full h-full object-center object-cover rounded-[10px]', 'data-gallery-images' => json_encode( $gallery_image_srcs ) ) ) : '';
    }
}

if ( ! function_exists( 'dali_template_loop_video_poster' ) ) {
    /**
     * videos poster in the loop.
     */
    function dali_template_loop_video_poster() {
        echo dali_get_video_loop_thumbnail ( 'dali_video_medium' );
    }
}


if ( ! function_exists( 'dali_template_loop_video_link_open' ) ) {
    /**
     * Insert the opening anchor tag for videos in the loop.
     */
    function dali_template_loop_video_link_open() {
        global $video;

        $link = apply_filters( 'dali_loop_video_link', get_the_permalink(), $video );

        echo '<a href="' . esc_url( $link ) . '" class="aspect-w-16 aspect-h-9 block">';
    }
}

if ( ! function_exists( 'dali_template_loop_video_poster' ) ) {
    /**
     * videos poster in the loop.
     */
    function dali_template_loop_video_poster() {
        echo dali_get_video_thumbnail ( 'masvideos_video_medium' );
    }
}


if ( ! function_exists( 'dali_template_loop_video_link_close' ) ) {
    /**
     * Insert the opening anchor tag for videos in the loop.
     */
    function dali_template_loop_video_link_close() {
        echo '</a>';
    }
}

if ( ! function_exists( 'dali_template_loop_video_title_open' ) ) {

    /**
     * Show the video title in the video loop. By default this is an H4.
     */
    function dali_template_loop_video_title_open() {
        echo '<h6 class="text-base font-bold">';
    }
}

if ( ! function_exists( 'dali_template_loop_video_title_link' ) ) {
    /**
     * Insert the opening anchor tag for videos in the loop.
     */
    function dali_template_loop_video_title_link() {
        global $video;

        $link = apply_filters( 'dali_loop_video_link', get_the_permalink(), $video );

        the_title ( '<a href="' . esc_url( $link ) . '" class="">', '</a>' );
    }
}

if ( ! function_exists( 'dali_template_loop_video_title_close' ) ) {

    /**
     * Show the video title in the video loop. By default this is an H3.
     */
    function dali_template_loop_video_title_close() {
        echo '</h6>';
    }
}


if ( ! function_exists( 'dali_template_loop_video_item_close' ) ) {

    /**
     * Videos meta close in the video meta.
     */
    function dali_template_loop_video_item_close() {
        echo '</div>';
    }
}

if ( ! function_exists( 'dali_template_loop_video_meta_wrap_open' ) ) {

    /**
     * video meta wrap open in the video loop.
     */
    function dali_template_loop_video_meta_wrap_open() {
        ?>
        <ul class="lg:flex space-y-1 lg:space-y-0 lg:space-x-3 video__meta list-unstyled">
        <?php
    }
}

if ( ! function_exists( 'dali_template_loop_video_meta_wrap_close' ) ) {

    /**
     * video meta wrap close in the video loop.
     */
    function dali_template_loop_video_meta_wrap_close() {
        ?>
        </ul>
        <?php
    }
}

if ( ! function_exists( 'dali_template_loop_video_meta' ) ) {

    /**
     * video meta in the video loop.
     */
    function dali_template_loop_video_meta() {
        echo '<li class="video__meta--last-update text-da-gray-100">' . human_time_diff( get_post_time( 'U' ), current_time( 'timestamp' ) ) . ' ' .  esc_html__( 'ago', 'dali' ) . '</li>';
    }
}

if ( ! function_exists( 'dali_template_loop_video_body_open' ) ) {
    function dali_template_loop_video_body_open() {
        ?><div class="space-y-3 2xl:space-y-0 pt-0.5 video-meta"><div class="space-y-1"><?php
    }
}

if ( ! function_exists( 'dali_template_loop_video_body_close' ) ) {
    function dali_template_loop_video_body_close() {
        ?></div></div><?php
    }
}


if ( ! function_exists( 'dali_template_video_genres' ) ) {
    /**
     * Video categories in the video.
     */
    function dali_template_video_genres() {
        global $video;

        $categories = get_the_term_list( $video->get_id(), 'video_cat', '', ', ' );

        if( ! empty ( $categories ) ) {
            echo sprintf( '<li class="text-da-primary">%s</li><li class="text-da-gray-100">-</li>', $categories );
        }
    }
}