<?php
/**
 * Dali OCDI Class
 *
 * @package mytavel
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'Dali_OCDI' ) ) :
	/**
	 * The one click demo import class.
	 */
	class Dali_OCDI {

		/**
		 * Stores the assets URL.
		 *
		 * @var string
		 */
		public $assets_url;

		/**
		 * Stores the demo URL.
		 *
		 * @var string
		 */
		public $demo_url;

		/**
		 * Instantiate the class.
		 */
		public function __construct() {

			$this->assets_url = 'https://transvelo.github.io/dali/assets/';
			$this->demo_url   = 'https://dali.madrasthemes.com/';

			add_filter( 'pt-ocdi/confirmation_dialog_options', [ $this, 'confirmation_dialog_options' ], 10, 1 );

			add_action( 'pt-ocdi/import_files', [ $this, 'import_files' ] );

			add_action( 'pt-ocdi/after_import', [ $this, 'import_wpforms' ] );
			add_action( 'pt-ocdi/enable_wp_customize_save_hooks', '__return_true' );
			add_filter( 'pt-ocdi/disable_pt_branding', '__return_true' );
			add_action( 'pt-ocdi/after_import', [ $this, 'set_site_options' ] );
			add_filter( 'ocdi/register_plugins', [ $this, 'register_plugins' ] );

		}

		/**
		 * Register plugins in OCDI.
		 *
		 * @param array $plugins List of plugins.
		 */
		public function register_plugins( $plugins ) {
			global $dali;

			$profile = 'default';

			if ( isset( $_GET['import'] ) ) { // phpcs:ignore WordPress.Security.NonceVerification.Recommended
				$demo_id = absint( $_GET['import'] ); // phpcs:ignore WordPress.Security.NonceVerification.Recommended
				switch ( $demo_id ) {
					case 7:
						$profile = 'elementor';
						break;
				}
			}

			return $dali->plugin_install->get_demo_plugins( $profile );
		}

		/**
		 * Confirmation dialog box options.
		 *
		 * @param array $options The dialog options.
		 * @return array
		 */
		public function confirmation_dialog_options( $options ) {
			return array_merge(
				$options,
				array(
					'width' => 410,
				)
			);
		}

		/**
		 * Trigger after import
		 */
		public function trigger_ocdi_after_import() {
			$import_files    = $this->import_files();
			$selected_import = end( $import_files );
			do_action( 'pt-ocdi/after_import', $selected_import ); //phpcs:ignore WordPress.NamingConventions.ValidHookName.UseUnderscores
		}

		/**
		 * Replace uploads Dir.
		 *
		 * @param array $selected_import The import that just ran.
		 */
		public function replace_uploads_dir( $selected_import ) {
			if ( isset( $selected_import['uploads_dir'] ) ) {
				$from = $selected_import['uploads_dir'] . '/';
			} else {
				$from = 'https://dali.madrasthemes.com/';
			}

			$site_upload_dir = wp_get_upload_dir();
			$to              = $site_upload_dir['baseurl'] . '/';
			\Elementor\Utils::replace_urls( $from, $to );
		}

		/**
		 * Set site options.
		 *
		 * @param array $selected_import The import that just ran.
		 */
		public function set_site_options( $selected_import ) {

			if ( isset( $selected_import['set_pages'] ) && $selected_import['set_pages'] ) {
				$front_page_title = isset( $selected_import['front_page_title'] ) ? $selected_import['front_page_title'] : 'Home Main';
				$front_page_id              = get_page_by_title( $front_page_title );
				$blog_page_id               = get_page_by_title( 'Blog' );
				$myaccount_page_id          = get_page_by_title( 'My Account' );
			    $movies_page_id             = get_page_by_title( 'Movies' );
			    $tv_shows_page_id           = get_page_by_title( 'TV Shows' );
			    $videos_page_id             = get_page_by_title( 'Videos' );
			    $persons_page_id            = get_page_by_title( 'Persons' );

				update_option( 'show_on_front', 'page' );
				update_option( 'page_on_front', $front_page_id->ID );
				update_option( 'page_for_posts', $blog_page_id->ID );
				update_option( 'masvideos_myaccount_page_id', $myaccount_page_id->ID );
			    update_option( 'masvideos_movies_page_id', $movies_page_id->ID );
			    update_option( 'masvideos_tv_shows_page_id', $tv_shows_page_id->ID );
			    update_option( 'masvideos_videos_page_id', $videos_page_id->ID );
			    update_option( 'masvideos_persons_page_id', $persons_page_id->ID );

			     // Enable Reviews
			    update_option( 'masvideos_episode_review_rating_required', 'yes' );
			    update_option( 'masvideos_tv_show_review_rating_required', 'yes' );
			    update_option( 'masvideos_movie_review_rating_required', 'yes' );
			}

			if ( 'elementor' === $selected_import['plugin_profile'] ) {
			    if ( class_exists('MasVideos') ){
			        $masvideos_posttypes = array( 'movie', 'tv_show', 'video', 'post', 'page', 'episode' );
			        update_option( 'elementor_cpt_support', $masvideos_posttypes );
			    }
			}

			update_option( 'posts_per_page', 9 );

		}


		/**
		 * Set the nav menus.
		 *
		 * @param array $selected_import The import that just ran.
		 */
		public function set_nav_menus( $selected_import ) {
			if ( isset( $selected_import['set_nav_menus'] ) && $selected_import['set_nav_menus'] ) {
				$primary      = get_term_by( 'name', 'Primary Menu', 'nav_menu' );
				
				set_theme_mod( 'nav_menu_locations', $locations );
			}
		}

		/**
		 * Import WPForms.
		 */
		public function import_wpforms() {

			$ocdi_host = 'https://transvelo.github.io/dali';
			$dd_url    = $ocdi_host . '/assets/wpforms/';

			if ( ! function_exists( 'wpforms' ) || get_option( 'dali_wpforms_imported', false ) ) {
				return;
			}

			$wpform_file_url = $dd_url . 'all.json';
			$response        = wp_remote_get( $wpform_file_url );

			if ( is_wp_error( $response ) || 200 !== $response['response']['code'] ) {
				return;
			}

			$form_json = wp_remote_retrieve_body( $response );

			if ( is_wp_error( $form_json ) ) {
				return;
			}

			$forms = json_decode( $form_json, true );

			foreach ( $forms as $form_data ) {
				$form_title = $form_data['settings']['form_title'];

				if ( ! empty( $form_data['id'] ) ) {
					$form_content = array(
						'field_id' => '0',
						'settings' => array(
							'form_title' => sanitize_text_field( $form_title ),
							'form_desc'  => '',
						),
					);

					// Merge args and create the form.
					$form = array(
						'import_id'    => (int) $form_data['id'],
						'post_title'   => esc_html( $form_title ),
						'post_status'  => 'publish',
						'post_type'    => 'wpforms',
						'post_content' => wpforms_encode( $form_content ),
					);

					$form_id = wp_insert_post( $form );
				} else {
					// Create initial form to get the form ID.
					$form_id = wpforms()->form->add( $form_title );
				}

				if ( empty( $form_id ) ) {
					continue;
				}

				$form_data['id'] = $form_id;
				// Save the form data to the new form.
				wpforms()->form->update( $form_id, $form_data );
			}

			update_option( 'dali_wpforms_imported', true );
		}

		/**
		 * Import Files from each demo.
		 */
		public function import_files() {
			$ocdi_host   = 'https://transvelo.github.io/dali';
			$dd_url      = $ocdi_host . '/assets/xml/';
			$widget_url  = $ocdi_host . '/assets/widgets/';
			$preview_url = $ocdi_host . '/assets/img/ocdi/';
			/* translators: %1$s - The demo name. %2$s - Minutes. */
			$notice  = esc_html__( 'This demo will import %1$s. It may take %2$s', 'dali' );
			$notice .= '<br><br>' . esc_html__( 'Menus, Widgets and Settings will not be imported. Content imported already will not be imported.', 'dali' );
			$notice .= '<br><br>' . esc_html__( 'Alternatively, you can import this template directly into your page via Edit with Elementor.', 'dali' );

			return apply_filters(
				'dali_ocdi_files_args',
				array(
					array(
						'import_file_name'         => 'Full Demo - Gutenberg Blocks',
						'categories'               => array( 'Gutenberg Blocks' ),
						'import_file_url'          => $dd_url . 'full.xml',
						'import_preview_image_url' => $preview_url . 'full.jpg',
						'import_notice'            => esc_html__( 'It imports the entire demo. It may take upto 10 minutes', 'dali' ),
						'preview_url'              => 'https://dali.madrasthemes.com/',
						'plugin_profile'           => 'default',
						'set_nav_menus'            => true,
						'set_pages'                => true,
						'front_page_title'         => 'Home Main',
					),
					array(
						'import_file_name'         => 'Full Demo - Elementor',
						'categories'               => array( 'Elementor' ),
						'import_file_url'          => $dd_url . 'full-elementor.xml',
						'import_preview_image_url' => $preview_url . 'full.jpg',
						'import_notice'            => esc_html__( 'It imports the entire demo. It may take upto 15 minutes', 'dali' ),
						'preview_url'              => 'https://dali.madrasthemes.com/elementor',
						'plugin_profile'           => 'elementor',
						'set_nav_menus'            => true,
						'set_pages'                => true,
						'front_page_title'         => 'Home Main',
					),
				)
			);
		}
	}

endif;

return new Dali_OCDI();
